#!/usr/bin/python

#for env variables
import os
#to exit with return values
import sys

#authentication
from auth import auth
#atom feed
from atomfeed import atomfeed
#xml work
from atomxml import atomxml
#database interaction
from atomdb import atomdb
#http interaction
from http import http

class atom:
	"""This class handles the incoming connection and calls the proper method
	to handle the desired action.

	"""
	
	#var for file management
	db = atomdb()
	headers = http()

	def prepAuth(self):
		authtype = os.environ.get("HTTP_AUTHORIZATION")
		xwsse = os.environ.get("HTTP_X_WSSE")
		
		if not xwsse:
			self.headers.statusMsg(401, "Unauthorized", "WWW-Authenticate: WSSE realm=\"foo\", profile=\"UsernameToken\"")
			sys.exit(1)

		xwsse = xwsse.split(" ", 1)[1]
		login = {}
		for e in xwsse.split(","):
			e = e.lstrip().split("=", 1)
			login[e[0]] = e[1][1:-1]
		
		return login

	def doPost(self):
		self.headers.statusMsg(501, "Not implemented", "Not implemented")
		#authenticate
		login = self.prepAuth()
		if not auth().checkPass(login["Username"], login["Created"], login["Nonce"], login["PasswordDigest"]):
			self.headers.statusMsg(401, "Unauthorized", "Bad username or password")
			sys.exit(1)
		
		#get the body
		entry = sys.stdin.read()

		#need to check the content type header if not plain text
		#or xml reject

		if self.db.insert(entry):
			#success
			self.headers.statusMsg(201, "Created", "all good")
			print "Location: http://www.physcofish.com"
		else:
			self.headers.statusMsg(500, "Internal Service Error", "Could not add the new entry")


	def doPut(self, path):
		self.headers.statusMsg(501, "Not implemented", "Not implemented")
	
	def doDelete(self, path):
		self.headers.statusMsg(501, "Not implemented", "Not implemented")
	
	def doGet(self, path):
		#feed
		if path[0:5] == "/feed":
			#atomfeed.py handles printing
			atomfeed().getfeed(path[6:])
		#article
		else:
			article = self.db.find(path[1:])
			if article == None:
				#article not found
				self.headers.statusMsg(404, "Article not found", "Article not found")
			else:
				#return the xml of the story
				#get the article
				article = self.db.getentry(article[0][0])
				axml = atomxml().feedentry(article[0], article[1], article[2], article[3])
				#return the article
				print "Content-Type: text/xml\n"
				print "<?xml version=\"1.0\" encoding=\"utf-8\"?>"
				print "<entry xmlns=\"http://www.w3.org/2005/Atom\" xml:lang=\"en-US\">"
				#remove entry tags
				print axml[8:-10]
				print "</entry>"

	def action(self):
		requestType = os.environ.get("REQUEST_METHOD")
		path = os.environ.get("PATH_INFO")
		if requestType == "POST":
			self.doPost()
		elif requestType == "PUT":
			self.doPut(path)
		elif requestType == "DELETE":
			self.doDelete(path)
		elif requestType == "GET":
			self.doGet(path)
		else:
			#lighttpd seems to respond for this
			self.headers.statusMsg(400, "Bad Request", "Could not determine your request type")
			sys.exit(1)

if __name__ == '__main__':
	pass
	#atom().doGet("/20070325-2")
	#atom().action()
