#! /usr/bin/python
from xml.dom import minidom
import datetime

class atomxml:
	
	def feedentry(self, elements, authors, contributers, categories):
		entry = "<entry>\n<title>"+elements[1]+"</title>\n"
		#entry += "<link rel=\"alternate\" href=\""+elements[3]+"\"/>\n"
		entry += "<id>http://physcofish.com/entry.php?id="+elements[4]+"</id>\n"
		entry += "<published>"+elements[5].strftime("%Y-%m-%dT%H:%M:%SZ")+"</published>\n"
		entry += "<updated>"+elements[6].strftime("%Y-%m-%dT%H:%M:%SZ")+"</updated>\n"
		entry += "<summary>"+elements[7]+"</summary>\n"
		entry += "<content type=\""+elements[10]+"\">"+elements[8]+"</content>\n"
		entry += "<rights>"+elements[9]+"</rights>\n"
		for author in authors:
			entry += "<author>\n<name>"+author[1]+"</name>\n</author>\n"
			#need stuff for email and url
		for contributer in contributers:
			entry += "<contributer>\n<name>"+contributer[1]+"<name>\n</contributer>\n"
		#need to update if cateogry is not req
		#and to properly format multiple categories
		#entry += "<category term=\""+categories[1]+"\" />\n</entry>\n"
		for category in categories:
			entry += "<category term=\""+category+"\" />\n"	
		entry += "</entry>\n"

		return entry

	def parseentry(self, entry):
		"""Pulls the elements of an entry out of atom xml.
		Currently it will not work on malformed entries.
		Need to stop inserting "" for nonpresent optional entries, other classes should handle those themselves I think.

		"""
		
		elements = {}
		authors = []
		contributers = []
		categories = []
		
		try:
			dom = minidom.parseString(entry)
		#except minidom.ExpatError, e:
		except Exception, e:
			return None

		dom.normalize()

		#updated req
		tmp = dom.getElementsByTagName("updated")
		if not tmp:
			return None
		elements["updated"] = tmp[0].childNodes[0].toxml()

		#id req, atomdb creates this on insert so it can be missing
		tmp = dom.getElementsByTagName("id")
		if tmp:
			elements["id"] = tmp[0].childNodes[0].toxml()

		#title req
		tmp = dom.getElementsByTagName("title")
		if not tmp:
			return None
		elements["title"] = tmp[0].childNodes[0].toxml()

		#subtitle opt
		tmp = dom.getElementsByTagName("subtitle")
		if tmp:
			elements["subtitle"] = tmp[0].childNodes[0].toxml()
		else:
			elements["subtitle"] = ""

		#published opt, atomdb adds if missing on inserts
		tmp = dom.getElementsByTagName("published")
		if tmp:
			elements["published"] = tmp[0].childNodes[0].toxml()
		else:
			elements["published"] = ""

		#summary opt
		tmp = dom.getElementsByTagName("summary")
		if tmp:
			elements["summary"] = tmp[0].childNodes[0].toxml()
		else:
			elements["summary"] = ""

		#content opt
		tmp = dom.getElementsByTagName("content")
		if tmp:
			elements["content"] = tmp[0].childNodes[0].toxml()
			elements["ctype"] = tmp[0].getAttribute("type")
		else:
			elements["content"] = ""
			elements["ctype"] = ""

		#rights opt
		tmp = dom.getElementsByTagName("rights")
		if tmp:
			elements["rights"] = tmp[0].childNodes[0].toxml()
		else:
			elements["rights"] = ""

		#src opt
		tmp = dom.getElementsByTagName("src")
		if tmp:
			elements["src"] = tmp[0].childNodes[0].toxml()
		else:
			elements["src"] = ""

		#authors
		for author in dom.getElementsByTagName("author"):
			newauthor = {}
			
			#name req
			tmp = author.getElementsByTagName("name")
			if not tmp:
				return None
			newauthor["name"] = tmp[0].childNodes[0].toxml()
			
			#uri opt
			tmp = author.getElementsByTagName("uri")
			if tmp:
				newauthor["uri"] = tmp[0].childNodes[0].toxml()
			else:
				newauthor["uri"] = ""
			
			#email opt
			tmp = author.getElementsByTagName("email")
			if tmp:
				newauthor["email"] = tmp[0].childNodes[0].toxml()
			else:
				newauthor["email"] = ""
			
			#allow nick specification, its not in the standard?

			authors.append(newauthor)

		#contributers
		for contributer in dom.getElementsByTagName("contributer"):
			newcontributer = {}
			
			#name req
			tmp = contributer.getElementsByTagName("name")
			if not tmp:
				return None
			newcontributer["name"] = contributer[0].childNodes[0].toxml()

			#uri opt
			tmp = contributer.getElementsByTagName("uri")
			if tmp:
				newcontributer["uri"] = contributer[0].childNodes[0].toxml()
			else:
				newcontributer["uri"] = ""

			#email opt
			tmp = contributer.getElementsByTagName("email")
			if tmp:
				newcontributer["email"] = contributer[0].childNodes[0].toxml()
			else:
				newcontributer["email"] = ""

			#allow nick specification, its not in the standard?
						
			contributers.append(newcontributer)
		
		#categories opt
		tmp = dom.getElementsByTagName("category")
		if tmp:
			category = tmp[0].getAttribute("term")
			categories = category.split(" ")

		return  {"entry":elements, "authors":authors, "contributers":contributers, "categories":categories}
		

if __name__ == "__main__":
	pass
	#test = atomxml()
	#file = open("atomentry.xml", "r")
	#entry = file.read()
	#print test.parsexml(entry)
